@@ -38,13 +38,11 @@
 #include <QShowEvent>
 #include <QStringList>
 #include <QStyleFactory>
-#include <cassert>
-#include <iostream>
-#include <typeinfo>
 #include "Common.h"
 #include "CroppedActiveLayerProxy.h"
 #include "CroppedImageListProxy.h"
 #include "DialogSettings.h"
+#include "FilterGuiDynamismCache.h"
 #include "FilterSelector/FavesModelReader.h"
 #include "FilterSelector/FiltersPresenter.h"
 #include "FilterTextTranslator.h"
@@ -55,7 +53,6 @@
 #include "LayersExtentProxy.h"
 #include "Logger.h"
 #include "Misc.h"
-#include "OverrideCursor.h"
 #include "ParametersCache.h"
 #include "PersistentMemory.h"
 #include "Settings.h"
@@ -104,15 +101,18 @@ MainWindow::MainWindow(QWidget * parent) : QMainWindow(parent), ui(new Ui::MainW
   tsp.append(QString("/usr/share/icons/gnome"));
   QIcon::setThemeSearchPaths(tsp);
 
-  _filterUpdateWidgets = {ui->previewWidget, ui->zoomLevelSelector, ui->filtersView,  ui->filterParams,      ui->tbUpdateFilters, ui->pbFullscreen, ui->pbSettings,
-                          ui->pbOk,          ui->pbApply,           ui->pbClose,      ui->tbResetParameters, ui->tbCopyCommand,   ui->searchField,  ui->cbPreview,
-                          ui->tbAddFave,     ui->tbRemoveFave,      ui->tbRenameFave, ui->tbExpandCollapse,  ui->tbSelectionMode};
+  _filterUpdateWidgets = {ui->previewWidget, ui->zoomLevelSelector, ui->filtersView,  ui->filterParams,      ui->tbUpdateFilters, ui->pbFullscreen,         ui->pbSettings,
+                          ui->pbOk,          ui->pbApply,           ui->pbClose,      ui->tbResetParameters, ui->tbCopyCommand,   ui->searchField,          ui->cbPreview,
+                          ui->tbAddFave,     ui->tbRemoveFave,      ui->tbRenameFave, ui->tbExpandCollapse,  ui->tbSelectionMode, ui->tbRandomizeParameters};
 
   ui->tbAddFave->setToolTip(tr("Add fave"));
 
   ui->tbResetParameters->setToolTip(tr("Reset parameters to default values"));
   ui->tbResetParameters->setVisible(false);
 
+  ui->tbRandomizeParameters->setToolTip(tr("Randomize parameters"));
+  ui->tbRandomizeParameters->setVisible(false);
+
   QShortcut * copyShortcut = new QShortcut(QKeySequence::Copy, this);
   copyShortcut->setContext(Qt::ApplicationShortcut);
   connect(copyShortcut, &QShortcut::activated, [this] { ui->tbCopyCommand->animateClick(); });
@@ -213,6 +213,7 @@ MainWindow::MainWindow(QWidget * parent) : QMainWindow(parent), ui(new Ui::MainW
 
   loadSettings();
   ParametersCache::load(!_newSession);
+  FilterGuiDynamismCache::load();
   setIcons();
   QAction * escAction = new QAction(this);
   escAction->setShortcut(QKeySequence(Qt::Key_Escape));
@@ -245,6 +246,7 @@ MainWindow::~MainWindow()
 {
   saveCurrentParameters();
   ParametersCache::save();
+  FilterGuiDynamismCache::save();
   saveSettings();
   Logger::setMode(Logger::Mode::StandardOutput); // Close log file, if necessary
   delete ui;
@@ -260,6 +262,7 @@ void MainWindow::setIcons()
   ui->pbApply->setIcon(IconLoader::load("system-run"));
   ui->pbOk->setIcon(IconLoader::load("insert-image"));
   ui->tbResetParameters->setIcon(IconLoader::load("view-refresh"));
+  ui->tbRandomizeParameters->setIcon(IconLoader::load("randomize"));
   ui->tbCopyCommand->setIcon(IconLoader::load("edit-copy"));
   ui->pbClose->setIcon(IconLoader::load("close"));
   ui->pbCancel->setIcon(IconLoader::load("cancel"));
@@ -643,6 +646,7 @@ void MainWindow::makeConnections()
   connect(ui->pbClose, &QPushButton::clicked, this, &MainWindow::close);
   connect(ui->pbApply, &QPushButton::clicked, this, &MainWindow::onApplyClicked);
   connect(ui->tbResetParameters, &QToolButton::clicked, this, &MainWindow::onReset);
+  connect(ui->tbRandomizeParameters, &QToolButton::clicked, this, &MainWindow::onRandomizeParameters);
   connect(ui->tbCopyCommand, &QToolButton::clicked, this, &MainWindow::onCopyGMICCommand);
   connect(ui->tbUpdateFilters, &QToolButton::clicked, this, &MainWindow::onUpdateFiltersClicked);
   connect(ui->pbSettings, &QPushButton::clicked, this, &MainWindow::onSettingsClicked);
@@ -665,6 +669,7 @@ void MainWindow::makeConnections()
   connect(ui->progressInfoWidget, &ProgressInfoWidget::canceled, this, &MainWindow::onProgressionWidgetCancelClicked);
   connect(ui->tbSelectionMode, &QToolButton::toggled, this, &MainWindow::onFiltersSelectionModeToggled);
   connect(&_processor, &GmicProcessor::previewImageAvailable, this, &MainWindow::onPreviewImageAvailable);
+  connect(&_processor, &GmicProcessor::guiDynamismRunDone, this, &MainWindow::onGUIDynamismRunDone);
   connect(&_processor, &GmicProcessor::previewCommandFailed, this, &MainWindow::onPreviewError);
   connect(&_processor, &GmicProcessor::fullImageProcessingFailed, this, &MainWindow::onFullImageProcessingError);
   connect(&_processor, &GmicProcessor::fullImageProcessingDone, this, &MainWindow::onFullImageProcessingDone);
@@ -679,22 +684,26 @@ void MainWindow::onPreviewUpdateRequested()
   onPreviewUpdateRequested(false);
 }
 
-void MainWindow::onPreviewUpdateRequested(bool synchronous)
+void MainWindow::onPreviewUpdateRequested(bool synchronous, bool randomized)
 {
-  if (!ui->cbPreview->isChecked()) {
-    ui->previewWidget->invalidateSavedPreview();
-    return;
-  }
-  _processor.init();
-  if (_filtersPresenter->currentFilter().isNoPreviewFilter()) {
+  const FiltersPresenter::Filter currentFilter = _filtersPresenter->currentFilter();
+  if (currentFilter.isNoPreviewFilter()) {
     ui->previewWidget->displayOriginalImage();
     return;
   }
+  FilterGuiDynamism dynamism = FilterGuiDynamismCache::getValue(currentFilter.hash);
+  if (!ui->cbPreview->isChecked() && (dynamism == FilterGuiDynamism::Static)) {
+    ui->previewWidget->invalidateSavedPreview();
+    return;
+  }
   ui->tbUpdateFilters->setEnabled(false);
-
-  const FiltersPresenter::Filter currentFilter = _filtersPresenter->currentFilter();
+  _processor.init();
   GmicProcessor::FilterContext context;
-  context.requestType = synchronous ? GmicProcessor::FilterContext::RequestType::SynchronousPreview : GmicProcessor::FilterContext::RequestType::Preview;
+  if (!ui->cbPreview->isChecked()) {
+    context.requestType = GmicProcessor::FilterContext::RequestType::GUIDynamismRun;
+  } else {
+    context.requestType = synchronous ? GmicProcessor::FilterContext::RequestType::SynchronousPreview : GmicProcessor::FilterContext::RequestType::Preview;
+  }
   GmicProcessor::FilterContext::VisibleRect & rect = context.visibleRect;
   ui->previewWidget->normalizedVisibleRect(rect.x, rect.y, rect.w, rect.h);
 
@@ -705,10 +714,12 @@ void MainWindow::onPreviewUpdateRequested(bool synchronous)
   context.previewWindowHeight = ui->previewWidget->height();
   context.previewTimeout = Settings::previewTimeout();
   // context.filterName = currentFilter.plainTextName; // Unused in this context
-  // context.filterHash = currentFilter.hash; // Unused in this context
+  context.filterHash = currentFilter.hash;
   context.filterCommand = currentFilter.previewCommand;
   context.filterArguments = ui->filterParams->valueString();
   context.previewFromFullImage = currentFilter.previewFromFullImage;
+  context.previewCheckBox = ui->cbPreview->isChecked();
+  context.randomized = randomized;
   _processor.setContext(context);
   _processor.execute();
 
@@ -756,6 +767,16 @@ void MainWindow::onPreviewImageAvailable()
   ui->tbUpdateFilters->setEnabled(true);
 }
 
+void MainWindow::onGUIDynamismRunDone()
+{
+  ui->filterParams->setValues(_processor.gmicStatus(), false);
+  ui->filterParams->setVisibilityStates(_processor.parametersVisibilityStates());
+  if (ui->filterParams->hasKeypoints()) {
+    ui->previewWidget->setKeypoints(ui->filterParams->keypoints());
+  }
+  ui->tbUpdateFilters->setEnabled(true);
+}
+
 void MainWindow::onPreviewError(const QString & message)
 {
   ui->previewWidget->setPreviewErrorMessage(message);
@@ -803,6 +824,8 @@ void MainWindow::processImage()
   context.filterFullPath = currentFilter.fullPath;
   context.filterHash = currentFilter.hash;
   context.filterCommand = currentFilter.command;
+  context.previewCheckBox = ui->cbPreview->isChecked();
+  context.randomized = false;
   ui->filterParams->updateValueString(false); // Required to get up-to-date values of text parameters
   context.filterArguments = ui->filterParams->valueString();
   context.previewFromFullImage = false;
@@ -946,6 +969,21 @@ void MainWindow::onReset()
   }
 }
 
+void MainWindow::onRandomizeParameters()
+{
+  if (_filtersPresenter->currentFilter().isNoPreviewFilter()) {
+    return;
+  }
+  ui->filterParams->randomize();
+  if (ui->filterParams->hasKeypoints()) {
+    ui->previewWidget->setKeypoints(ui->filterParams->keypoints());
+  }
+  ui->previewWidget->invalidateSavedPreview();
+  clearMessage();
+  clearRightMessage();
+  onPreviewUpdateRequested(false, true);
+}
+
 void MainWindow::onCopyGMICCommand()
 {
   QClipboard * clipboard = QGuiApplication::clipboard();
@@ -1191,6 +1229,7 @@ void MainWindow::activateFilter(bool resetZoom, const QList<QString> & values)
     ui->previewWidget->setKeypoints(KeypointList());
   } else {
     ui->previewWidget->setKeypoints(ui->filterParams->keypoints());
+    ui->tbRandomizeParameters->setEnabled(ui->filterParams->acceptRandom());
   }
   setFilterName(FilterTextTranslator::translate(filter.name));
   ui->inOutSelector->enable();
@@ -1227,6 +1266,7 @@ void MainWindow::activateFilter(bool resetZoom, const QList<QString> & values)
   setZoomConstraint();
   _okButtonShouldApply = true;
   ui->tbResetParameters->setVisible(true);
+  ui->tbRandomizeParameters->setVisible(true);
   ui->tbCopyCommand->setVisible(true);
   ui->tbRemoveFave->setEnabled(filter.isAFave);
   ui->tbRenameFave->setEnabled(filter.isAFave);
@@ -1244,6 +1284,7 @@ void MainWindow::setNoFilter()
   ui->tbAddFave->setEnabled(false);
   ui->tbCopyCommand->setVisible(false);
   ui->tbResetParameters->setVisible(false);
+  ui->tbRandomizeParameters->setVisible(false);
   ui->zoomLevelSelector->showWarning(false);
   _okButtonShouldApply = false;
   ui->tbRemoveFave->setEnabled(_filtersPresenter->danglingFaveIsSelected());
